package implement

import (
	"code.fnuoos.com/zhimeng/model.git/src/dao"
	"code.fnuoos.com/zhimeng/model.git/src/model"
	zhios_order_relate_logx "code.fnuoos.com/zhimeng/model.git/utils/logx"
	"reflect"
	"xorm.io/xorm"
)

func NewAgentDb(engine *xorm.Engine) dao.AgentDao {
	return &AgentDb{Db: engine}
}

type AgentDb struct {
	Db *xorm.Engine
}

func (a AgentDb) GetAgentByUsername(username string) (agent *model.Agent, err error) {
	agent = new(model.Agent)
	has, err := a.Db.Where("username =?", username).Get(agent)
	if err != nil {
		return nil, zhios_order_relate_logx.Error(err)
	}
	if has == false {
		return nil, nil
	}
	return agent, nil
}

func (a AgentDb) AgentInsert(m *model.Agent) (int64, error) {
	insertAffected, err := a.Db.InsertOne(m)
	if err != nil {
		return 0, err
	}
	return insertAffected, nil
}

func (a AgentDb) AgentDeleteBySession(session *xorm.Session, id interface{}) (int64, error) {
	if reflect.TypeOf(id).Kind() == reflect.Slice {
		return session.In("id", id).Delete(model.Admin{})
	} else {
		return session.Where("id = ?", id).Delete(model.Admin{})
	}
}

func (a AgentDb) UpdateAgent(m *model.Agent, columns ...string) (int64, error) {
	affected, err := a.Db.Where("id =?", m.Id).Cols(columns...).Update(m)
	if err != nil {
		return 0, err
	}
	return affected, nil
}

func (a AgentDb) GetAgentRolePermission(id int) (list []*dao.AgentWithRolePermission, total int64, err error) {
	total, err = a.Db.Where("agent.id =?", id).
		Join("LEFT", "agent_with_role", "agent.id = agent_with_role.agent_id").
		Join("LEFT", "agent_role", "admin_with_role.role_id = agent_role.id").
		Join("LEFT", "agent_role_permission_group", "agent_role.id = agent_role_permission_group.role_id").
		Join("LEFT", "agent_permission_group", "agent_role_permission_group.group_id = agent_permission_group.id").
		Join("LEFT", "agent_permission_group_permission", "agent_permission_group.id = agent_permission_group_permission.group_id").
		Join("LEFT", "agent_permission", "agent_permission_group_permission.permission_id = agent_permission.id").
		FindAndCount(&list)
	return
}

func (a AgentDb) FindAdmin(username string, state, page, limit int) (list []model.Agent, total int64, err error) {
	sess := a.Db.Desc("id").Limit(limit, (page-1)*limit)
	if username != "" {
		sess.And("username like ?", "%"+username+"%")
	}
	if state != 0 {
		sess.And("state = ?", state)
	}
	total, err = sess.FindAndCount(&list)
	if err != nil {
		return nil, 0, err
	}
	return
}

func (a AgentDb) GetAgent(id int) (m *model.Agent, err error) {
	m = new(model.Agent)
	has, err := a.Db.Where("id =?", id).Get(m)
	if err != nil {
		return nil, zhios_order_relate_logx.Error(err)
	}
	if has == false {
		return nil, nil
	}
	return m, nil
}

func (a AgentDb) FindAgentRolePermissionGroup(id int) (list []*dao.AgentWithRolePermissionGroup, total int64, err error) {
	total, err = a.Db.Where("agent.id =?", id).
		Join("LEFT", "agent_with_role", "agent.id = agent_with_role.agent_id").
		Join("LEFT", "agent_role", "agent_with_role.role_id = agent_role.id").
		FindAndCount(&list)
	return
}
func (a AgentDb) GetSuperAdmin(agentId int) (list *model.Agent) {
	list = new(model.Agent)
	sess := a.Db.Where("is_super_administrator=1 and agent_id=?", agentId)
	get, err := sess.Get(list)
	if err != nil || get == false {
		return nil
	}
	return list
}
func (a AgentDb) GetSuperAgentByUsername(username string) (agent *model.Agent, err error) {
	agent = new(model.Agent)
	has, err := a.Db.Where("is_super_administrator=1 and username =?", username).Get(agent)
	if err != nil {
		return nil, zhios_order_relate_logx.Error(err)
	}
	if has == false {
		return nil, nil
	}
	return agent, nil
}
