package implement

import (
	"code.fnuoos.com/zhimeng/model.git/src/dao"
	"code.fnuoos.com/zhimeng/model.git/src/model"
	zhios_order_relate_logx "code.fnuoos.com/zhimeng/model.git/utils/logx"
	"xorm.io/xorm"
)

func NewAppletApplicationAdSpaceListDb(engine *xorm.Engine) dao.AppletApplicationAdSpaceListDao {
	return &AppletApplicationAdSpaceListDb{Db: engine}
}

type AppletApplicationAdSpaceListDb struct {
	Db *xorm.Engine
}

func (a AppletApplicationAdSpaceListDb) FindAppletApplicationAdSpaceListByIds(id []string) (medium *[]model.AppletApplicationAdSpaceList, err error) {
	medium = new([]model.AppletApplicationAdSpaceList)
	err = a.Db.In("id", id).Find(medium)
	if err != nil {
		return nil, zhios_order_relate_logx.Error(err)
	}
	return medium, nil
}
func (a AppletApplicationAdSpaceListDb) FindAppletApplicationAdSpaceListByAppidIds(id string) (medium *[]model.AppletApplicationAdSpaceList, err error) {
	medium = new([]model.AppletApplicationAdSpaceList)
	err = a.Db.Where("app_id=?", id).Find(medium)
	if err != nil {
		return nil, zhios_order_relate_logx.Error(err)
	}
	return medium, nil
}
func (a AppletApplicationAdSpaceListDb) FindAppletApplicationAdSpaceListByMediumId(mediumId int) (medium *[]model.AppletApplicationAdSpaceList, err error) {

	medium = new([]model.AppletApplicationAdSpaceList)
	err = a.Db.Where("medium_id=?", mediumId).Find(medium)
	if err != nil {
		return nil, zhios_order_relate_logx.Error(err)
	}
	return medium, nil
}
func (a AppletApplicationAdSpaceListDb) FindAppletApplicationAdSpaceList(name, platform string, adType, state string, mediumId, page, limit int) (list []dao.AppletApplicationAdSpaceListGroup, total int64, err error) {
	sess := a.Db.Where("applet_application_ad_space_list.id>0").Desc("applet_application_ad_space_list.id")
	if page > 0 {
		sess.Limit(limit, (page-1)*limit)
	}
	if mediumId > 0 {
		sess.And("applet_application_ad_space_list.medium_id=?", mediumId)
	}
	if name != "" {
		sess.And("applet_application_ad_space_list.name like ? or applet_application_ad_space_list.ad_id like ?", "%"+name+"%", "%"+name+"%")
	}
	if platform != "" {
		sess.And("applet_application.platform = ?", platform)
	}
	if adType != "" {
		sess.And("applet_application_ad_space_list.kind = ?", adType)
	}
	if state != "" {
		sess.And("applet_application_ad_space_list.state = ?", state)
	}
	sess.Join("LEFT", "applet_application", "applet_application.app_id = applet_application_ad_space_list.app_id")
	total, err = sess.FindAndCount(&list)
	if err != nil {
		return nil, 0, err
	}
	return
}

func (a AppletApplicationAdSpaceListDb) GetAppletApplicationAdSpaceListByAdId(id string) (medium *model.AppletApplicationAdSpaceList, err error) {
	medium = new(model.AppletApplicationAdSpaceList)
	has, err := a.Db.Where("ad_id =?", id).Get(medium)
	if err != nil {
		return nil, zhios_order_relate_logx.Error(err)
	}
	if has == false {
		return nil, nil
	}
	return medium, nil
}

func (a AppletApplicationAdSpaceListDb) FindAllAppletApplicationAdSpaceListList(appId string) (list []model.AppletApplicationAdSpaceList, err error) {
	sess := a.Db.Where("app_id=?", appId).Desc("id")
	err = sess.Find(&list)
	if err != nil {
		return nil, err
	}
	return
}
