package implement

import (
	"code.fnuoos.com/zhimeng/model.git/src/super/dao"
	"code.fnuoos.com/zhimeng/model.git/src/super/model"
	zhios_order_relate_logx "code.fnuoos.com/zhimeng/model.git/utils/logx"
	"strings"
	"xorm.io/xorm"
)

func NewAgentListDb(engine *xorm.Engine) dao.AgentListDao {
	return &AgentListDb{Db: engine}
}

type AgentListDb struct {
	Db *xorm.Engine
}

func (a AgentListDb) GetAgentListBySession(session *xorm.Session, agentId int) (agent *model.AgentList, err error) {
	var mm model.AgentList
	if has, err := session.Where("agent_id = ?", agentId).
		Get(&mm); err != nil || has == false {
		return nil, zhios_order_relate_logx.Warn(err)
	}
	return &mm, nil
}

func (a AgentListDb) GetAgentList(agentId int) (agent *model.AgentList, err error) {
	agent = new(model.AgentList)
	has, err := a.Db.Where("agent_id =?", agentId).Get(agent)
	if err != nil {
		return nil, zhios_order_relate_logx.Error(err)
	}
	if has == false {
		return nil, nil
	}
	return agent, nil
}

func (a AgentListDb) AgentListInsert(m *model.AgentList) (int64, error) {
	insertAffected, err := a.Db.InsertOne(m)
	if err != nil {
		return 0, err
	}
	return insertAffected, nil
}

func (a AgentListDb) UpdateAgentList(m *model.AgentList, columns ...string) (int64, error) {
	affected, err := a.Db.Where("agent_id =?", m.Id).Cols(columns...).Update(m)
	if err != nil {
		return 0, err
	}
	return affected, nil
}
func (a AgentListDb) FindAgentList(uuid, name, state string, minState, page, limit int) (list []model.AgentList, total int64, err error) {
	sess := a.Db.Desc("id").Limit(limit, (page-1)*limit)
	if name != "" {
		sess.And("company_name like ?", "%"+name+"%")
	}
	if state != "" {
		sess.And("state = ?", state)
	}
	if uuid != "" {
		sess.And("uuid = ?", uuid)
	}
	if minState > 0 {
		sess.And("state >= ?", minState)
	}
	total, err = sess.FindAndCount(&list)
	if err != nil {
		return nil, 0, err
	}
	return
}

func (a AgentListDb) FindAgentListBySettleType(uuid, agentId, settleType string, page, limit int) (list []model.AgentList, total int64, err error) {
	sess := a.Db.Desc("id").Limit(limit, (page-1)*limit)

	if settleType != "" {
		sess.And("settle_type = ?", settleType)
	}
	if agentId != "" {
		sess.In("agent_id", strings.Split(agentId, ","))
	}
	if uuid != "" {
		sess.And("uuid = ?", uuid)
	}
	total, err = sess.FindAndCount(&list)
	if err != nil {
		return nil, 0, err
	}
	return
}
