package implement

import (
	"code.fnuoos.com/zhimeng/model.git/src/super/dao"
	"code.fnuoos.com/zhimeng/model.git/src/super/model"
	zhios_order_relate_logx "code.fnuoos.com/zhimeng/model.git/utils/logx"
	"strings"
	"xorm.io/xorm"
)

func NewAgentSettlementDb(engine *xorm.Engine) dao.AgentSettlementDao {
	return &AgentSettlementDb{Db: engine}
}

type AgentSettlementDb struct {
	Db *xorm.Engine
}

func (a AgentSettlementDb) UpdateAgentSettlementBySession(session *xorm.Session, agentSettlement *model.AgentSettlement, columns ...string) (int64, error) {
	affected, err := session.Where("id =?", agentSettlement.Id).Cols(columns...).Update(agentSettlement)
	if err != nil {
		return 0, err
	}
	return affected, nil
}

func (a AgentSettlementDb) GetAgentSettlementForAvailable(agentId int) (agentSettlement *model.AgentSettlement, err error) {
	agentSettlement = new(model.AgentSettlement)
	has, err := a.Db.Where("agent_id =?", agentId).And("state =?", 0).Get(agentSettlement)
	if err != nil {
		return nil, zhios_order_relate_logx.Error(err)
	}
	if has == false {
		return nil, nil
	}
	return agentSettlement, nil
}

func (a AgentSettlementDb) AgentSettlementInsertBySession(session *xorm.Session, m *model.AgentSettlement) (int64, error) {
	insertAffected, err := session.InsertOne(m)
	if err != nil {
		return 0, err
	}
	return insertAffected, nil
}

func (a AgentSettlementDb) GetAgentSettlementById(id int) (mediumSettlement *model.AgentSettlement, err error) {
	mediumSettlement = new(model.AgentSettlement)
	has, err := a.Db.Where("id =?", id).Get(mediumSettlement)
	if err != nil {
		return nil, zhios_order_relate_logx.Error(err)
	}
	if has == false {
		return nil, nil
	}
	return mediumSettlement, nil
}
func (a AgentSettlementDb) FindAgentSettlementList(uuid, agentId, appId, payState, state, startDate, endDate string, page, limit int) (list []model.AgentSettlement, total int64, err error) {
	sess := a.Db.OrderBy("start_date desc,id desc").Limit(limit, (page-1)*limit)
	if uuid != "" {
		sess.And("uuid = ?", uuid)
	}
	if payState != "" {
		sess.And("pay_state = ?", payState)
	}
	if state != "" {
		sess.And("state = ?", state)
	}
	if startDate != "" {
		sess.And("start_date>=?", startDate)
	}
	if endDate != "" {
		sess.And("end_date<=?", endDate)
	}
	if appId != "" {
		sess.In("app_id", strings.Split(appId, ","))
	}
	if agentId != "" {
		sess.In("agent_id", strings.Split(agentId, ","))
	}
	total, err = sess.FindAndCount(&list)
	if err != nil {
		return nil, 0, err
	}
	return
}
