package implement

import (
	"code.fnuoos.com/zhimeng/model.git/src/super/dao"
	"code.fnuoos.com/zhimeng/model.git/src/super/model"
	zhios_order_relate_logx "code.fnuoos.com/zhimeng/model.git/utils/logx"
	"strings"
	"xorm.io/xorm"
)

func NewGenerateWxAdDataDb(engine *xorm.Engine) dao.GenerateWxAdDataDao {
	return &GenerateWxAdDataDb{Db: engine}
}

type GenerateWxAdDataDb struct {
	Db *xorm.Engine
}

func (g GenerateWxAdDataDb) UpdateGenerateWxAdDataBySession(session *xorm.Session, m *model.GenerateWxAdData, columns ...string) (int64, error) {
	affected, err := session.Where("id =?", m.Id).Cols(columns...).Update(m)
	if err != nil {
		return 0, err
	}
	return affected, nil
}

func (g GenerateWxAdDataDb) GetGenerateWxAdData(id int) (data *model.GenerateWxAdData, err error) {
	data = new(model.GenerateWxAdData)
	has, err := g.Db.Where("id =?", id).Get(data)
	if err != nil {
		return nil, zhios_order_relate_logx.Error(err)
	}
	if has == false {
		return nil, nil
	}
	return data, nil
}

func (g GenerateWxAdDataDb) GenerateWxAdDataInsertBySession(session *xorm.Session, m *model.GenerateWxAdData) (int64, error) {
	insertAffected, err := session.InsertOne(m)
	if err != nil {
		return 0, err
	}
	return insertAffected, nil
}
func (g GenerateWxAdDataDb) FindGenerateWxAdDataList(uuid, appId, mediumId, slotId, startDate, endDate string, page, limit int) (list []model.GenerateWxAdData, total int64, err error) {
	sess := g.Db.OrderBy("date desc,id desc").Limit(limit, (page-1)*limit)
	if uuid != "" {
		sess.And("uuid = ?", uuid)
	}
	if startDate != "" {
		sess.And("date>=?", startDate)
	}
	if endDate != "" {
		sess.And("date<=?", endDate)
	}
	if appId != "" {
		sess.In("app_id", strings.Split(appId, ","))
	}
	if mediumId != "" {
		sess.In("medium_id", strings.Split(mediumId, ","))
	}
	if slotId != "" {
		sess.In("slot_id", strings.Split(slotId, ","))
	}
	total, err = sess.FindAndCount(&list)
	if err != nil {
		return nil, 0, err
	}
	return
}
func (g GenerateWxAdDataDb) FindGenerateWxAdDataListMedium(uuid, appId, mediumId, slotId, adType, startDate, endDate string, page, limit int) (list []model.GenerateWxAdData, total int64, err error) {
	sess := g.Db.Where("is_generate_report=1").OrderBy("date desc,id desc").Limit(limit, (page-1)*limit)
	if uuid != "" {
		sess.And("uuid = ?", uuid)
	}
	if startDate != "" {
		sess.And("date>=?", startDate)
	}
	if endDate != "" {
		sess.And("date<=?", endDate)
	}
	if appId != "" {
		sess.In("app_id", strings.Split(appId, ","))
	}
	if adType != "" {
		sess.In("slot_id", strings.Split(adType, ","))
	}
	if mediumId != "" {
		sess.In("medium_id", strings.Split(mediumId, ","))
	}
	if slotId != "" {
		sess.In("slot_id", strings.Split(slotId, ","))
	}
	total, err = sess.FindAndCount(&list)
	if err != nil {
		return nil, 0, err
	}
	return
}
func (g GenerateWxAdDataDb) FindGenerateWxAdDataListMediumAll(uuid, appId, mediumId, slotId, adType, startDate, endDate string, page, limit int) (list []model.GenerateWxAdData, err error) {
	sess := g.Db.Where("is_generate_report=1").OrderBy("date asc,id asc").Limit(limit, (page-1)*limit)
	if uuid != "" {
		sess.And("uuid = ?", uuid)
	}
	if startDate != "" {
		sess.And("date>=?", startDate)
	}
	if endDate != "" {
		sess.And("date<=?", endDate)
	}
	if appId != "" {
		sess.In("app_id", strings.Split(appId, ","))
	}
	if adType != "" {
		sess.In("slot_id", strings.Split(adType, ","))
	}
	if mediumId != "" {
		sess.In("medium_id", strings.Split(mediumId, ","))
	}
	if slotId != "" {
		sess.In("slot_id", strings.Split(slotId, ","))
	}
	err = sess.Find(&list)
	if err != nil {
		return nil, err
	}
	return
}
