package implement

import (
	"code.fnuoos.com/zhimeng/model.git/src/super/dao"
	"code.fnuoos.com/zhimeng/model.git/src/super/model"
	zhios_order_relate_logx "code.fnuoos.com/zhimeng/model.git/utils/logx"
	"strings"
	"xorm.io/xorm"
)

func NewMediumListDb(engine *xorm.Engine) dao.MediumListDao {
	return &MediumListDb{Db: engine}
}

type MediumListDb struct {
	Db *xorm.Engine
}

func (m MediumListDb) GetMediumListBySession(session *xorm.Session, mediumId int) (medium *model.MediumList, err error) {
	var mm model.MediumList
	if has, err := session.Where("medium_id = ?", mediumId).
		Get(&mm); err != nil || has == false {
		return nil, zhios_order_relate_logx.Warn(err)
	}
	return &mm, nil
}

func (m MediumListDb) GetMediumList(mediumId int) (medium *model.MediumList, err error) {
	medium = new(model.MediumList)
	has, err := m.Db.Where("medium_id =?", mediumId).Get(medium)
	if err != nil {
		return nil, zhios_order_relate_logx.Error(err)
	}
	if has == false {
		return nil, nil
	}
	return medium, nil
}

func (m MediumListDb) MediumListInsert(medium *model.MediumList) (int64, error) {
	insertAffected, err := m.Db.InsertOne(medium)
	if err != nil {
		return 0, err
	}
	return insertAffected, nil
}

func (m MediumListDb) UpdateMediumList(medium *model.MediumList, columns ...string) (int64, error) {
	affected, err := m.Db.Where("medium_id =?", medium.Id).Cols(columns...).Update(m)
	if err != nil {
		return 0, err
	}
	return affected, nil
}
func (m MediumListDb) FindMediumList(uuid, name, mediumId, state string, minState, page, limit int) (list []model.MediumList, total int64, err error) {
	sess := m.Db.Desc("id").Limit(limit, (page-1)*limit)
	if mediumId != "" {
		sess.In("medium_id", strings.Split(mediumId, ","))
	}
	if name != "" {
		sess.And("company_name like ?", "%"+name+"%")
	}
	if state != "" {
		sess.And("state = ?", state)
	}
	if uuid != "" {
		sess.And("uuid = ?", uuid)
	}
	if minState > 0 {
		sess.And("state >= ?", minState)
	}
	total, err = sess.FindAndCount(&list)
	if err != nil {
		return nil, 0, err
	}
	return
}

func (m MediumListDb) FindMediumListBySettleType(uuid, mediumId, settleType string, page, limit int) (list []model.MediumList, total int64, err error) {
	sess := m.Db.Desc("id").Limit(limit, (page-1)*limit)

	if settleType != "" {
		sess.And("settle_type = ?", settleType)
	}
	if mediumId != "" {
		sess.In("medium_id", strings.Split(mediumId, ","))
	}
	if uuid != "" {
		sess.And("uuid = ?", uuid)
	}
	total, err = sess.FindAndCount(&list)
	if err != nil {
		return nil, 0, err
	}
	return
}
