package implement

import (
	"code.fnuoos.com/zhimeng/model.git/src/super/dao"
	"code.fnuoos.com/zhimeng/model.git/src/super/model"
	zhios_order_relate_logx "code.fnuoos.com/zhimeng/model.git/utils/logx"
	"strings"
	"xorm.io/xorm"
)

func NewMediumSettlementDb(engine *xorm.Engine) dao.MediumSettlementDao {
	return &MediumSettlementDb{Db: engine}
}

type MediumSettlementDb struct {
	Db *xorm.Engine
}

func (m MediumSettlementDb) UpdateMediumSettlementBySession(session *xorm.Session, mediumSettlement *model.MediumSettlement, columns ...string) (int64, error) {
	affected, err := session.Where("id =?", mediumSettlement.Id).Cols(columns...).Update(mediumSettlement)
	if err != nil {
		return 0, err
	}
	return affected, nil
}

func (m MediumSettlementDb) MediumSettlementInsertBySession(session *xorm.Session, mediumSettlement *model.MediumSettlement) (int64, error) {
	insertAffected, err := session.InsertOne(mediumSettlement)
	if err != nil {
		return 0, err
	}
	return insertAffected, nil
}

func (m MediumSettlementDb) GetMediumSettlementForAvailable(mediumId int) (mediumSettlement *model.MediumSettlement, err error) {
	mediumSettlement = new(model.MediumSettlement)
	has, err := m.Db.Where("medium_id =?", mediumId).And("state =?", 0).Get(mediumSettlement)
	if err != nil {
		return nil, zhios_order_relate_logx.Error(err)
	}
	if has == false {
		return nil, nil
	}
	return mediumSettlement, nil
}
func (m MediumSettlementDb) GetMediumSettlementById(id int) (mediumSettlement *model.MediumSettlement, err error) {
	mediumSettlement = new(model.MediumSettlement)
	has, err := m.Db.Where("id =?", id).Get(mediumSettlement)
	if err != nil {
		return nil, zhios_order_relate_logx.Error(err)
	}
	if has == false {
		return nil, nil
	}
	return mediumSettlement, nil
}
func (m MediumSettlementDb) FindMediumSettlementList(uuid, mediumId, appId, payState, state, startDate, endDate string, page, limit int) (list []model.MediumSettlement, total int64, err error) {
	sess := m.Db.OrderBy("start_date desc,id desc").Limit(limit, (page-1)*limit)
	if uuid != "" {
		sess.And("uuid = ?", uuid)
	}
	if payState != "" {
		sess.And("pay_state = ?", payState)
	}
	if state != "" {
		sess.And("state = ?", state)
	}
	if startDate != "" {
		sess.And("start_date>=?", startDate)
	}
	if endDate != "" {
		sess.And("end_date<=?", endDate)
	}
	if appId != "" {
		sess.In("app_id", strings.Split(appId, ","))
	}
	if mediumId != "" {
		sess.In("medium_id", strings.Split(mediumId, ","))
	}
	total, err = sess.FindAndCount(&list)
	if err != nil {
		return nil, 0, err
	}
	return
}
